Crate factorio_prototypes_json

Crate factorio_prototypes_json 

Rust types that parse Factorio’s machine-readable JSON format.

Structs

BasicMembers
Several API members follow a common format for their basic fields.
Concept
A Concept is a type that the format uses and are commonly used as parts of a prototype.
CustomProperties
A special set of properties that the user can add an arbitrary number of.
Define
Defines can be recursive in nature, meaning one Define can have multiple sub-Defines that have the same structure. These are singled out as subkeys instead of values.
DefineValue
One of the values of a Define.
Image
An illustrative image shown next to a member.
Property
A property for a complex type.
Prototype
Prototypes are templates for components in the game engine. They define parameters which the engine uses to create predefined behavior.
PrototypeApi
The JSON, deserializable from the machine-readable JSON format file.
TypeLiteral
A literal value with an optional description. This is often used for enums or default values of properties.

Enums

Literal
A literal has the same format as a Type that is Type::Literal.
LoadingError
Errors that can occur while loading the JSON data with [load_prototypes_json].
PropertyDefault
The default value of a Property.
Type
A type field can be a string (Type::Simple), in which case that string is the simple type. Otherwise, a type is an enum and considered a complex type by the documentation.