Concept

Struct Concept 

pub struct Concept {
    pub basic: BasicMembers,
    pub parent: Option<String>,
    pub abstract: Option<bool>,
    pub inline: bool,
    pub type: Type,
    pub properties: Option<Vec<Property>>,
}
A Concept is a type that the format uses and are commonly used as parts of a prototype.

It is equivalent to the types page in the documentation.

Fields

basic: BasicMembers

The basic fields of the type.

parent: Option<String>

The name of the type’s parent, if any.

abstract: Option<bool>

Whether the type is abstract, and thus can’t be created directly.

inline: bool

Whether the type is inlined inside another property’s description.

type: Type

The type of the type/concept.

Either a propert Type, or the string "builtin", indicating a fundamental type like string or number.

TODO: If this is Type::Simple, constrain it to builtin`.

properties: Option<Vec<Property>>

The list of properties that the type has, if its type includes a struct.