pub struct CustomProperties {
pub description: String,
pub lists: Option<Vec<String>>,
pub examples: Option<Vec<String>>,
pub images: Option<Vec<Image>>,
pub key_type: Type,
pub value_type: Type,
}Expand description
A special set of properties that the user can add an arbitrary number of.
Specifies the type of the key and value of the custom property.
Fields
description: StringThe text description of the property.
lists: Option<Vec<String>>A list of Markdown lists to provide additional information. Usually contained in a spoiler tag.
examples: Option<Vec<String>>A list of code-only examples about the property.
images: Option<Vec<Image>>A list of illustrative images shown next to the property.
key_type: TypeThe type of the key of the custom property.
value_type: TypeThe type of the value of the custom property.